# frozen_string_literal: true

require 'axe-selenium'
require 'axe-rspec'
require 'rspec/core/formatters/base_text_formatter'

require 'stormbreaker/configuration'
require 'stormbreaker/axe_helper'
require 'stormbreaker/axe_matcher_auditor'
require 'stormbreaker/axe_results_reporter'
require 'stormbreaker/axe_rspec_auditor'
require 'stormbreaker/axe_violation_manager'
require 'stormbreaker/axe_violation'
require 'stormbreaker/erb_formatter'
require 'stormbreaker/axe_results_serializer'

module Stormbreaker
  autoload :VERSION, 'stormbreaker/version'

  def self.install!
    ::RSpec::Expectations::ExpectationTarget.prepend AxeRSpecAuditor
    ::Axe::Matchers::BeAxeClean.prepend AxeMatcherAuditor
    ::RSpec::Core::Formatters::BaseTextFormatter.prepend AxeResultsReporter
    configure_rspec_hooks
  end

  def self.configure_rspec_hooks
    RSpec.configure do |config|
      config.before(:each) do
        Stormbreaker::AxeHelper.post_test_cleanup
      end

      config.before(:suite) do
        Stormbreaker::AxeHelper.post_total_cleanup
      end

      config.after(:each) do
        unless Stormbreaker::AxeHelper.example_passed?
          raise RSpec::Expectations::ExpectationNotMetError, Stormbreaker::AxeHelper.detailed_results
        end
      end

      config.after(:suite) do
        erb_writer = Stormbreaker::ErbFormatter.new(Stormbreaker::AxeHelper.manager.total_violations)
        erb_writer.write_to_erb

        if Stormbreaker.configuration.serialize_output
          Stormbreaker::AxeResultsSerializer.serialize_results(Stormbreaker::AxeHelper.manager.total_violations)
        end
      end
    end
  end
end
