# frozen_string_literal: true

# ::Axe::Matchers::BeAxeClean.prepend AxeMatcherAuditor
module Stormbreaker
  class AxeHelper
    def self.assert_axe
      @driver ||= Stormbreaker.configured_driver
      raise 'Driver is not configured' unless @driver

      axe_matcher = Axe::Matchers::BeAxeClean.new
      axe_matcher.according_to configuration.rules
      axe_matcher.skipping configuration.skip

      # Always assert that driver's current page _is_ axe compliant
      RSpec::Expectations::PositiveExpectationHandler.handle_matcher(@driver, axe_matcher)
      call_stack = caller.select { |line| line =~ /selenium.*_spec\.rb/ }.first(5)
      # only get /path/to/spec:line_number from call stack
      call_stack.map! { |c| c.scan(%r{^[A-Za-z0-9/_-]*\.rb:\d*}) }

      violations = axe_matcher.audit([]).results.violations
      violations.each do |v|
        v.nodes.each do |node|
          manager.add_failure(called_by: call_stack, violation: v, node: node)
        end
      end
    end

    def self.manager
      @manager ||= AxeViolationManager.new
    end

    def self.post_test_cleanup
      manager.clear_failures_from_test
    end

    def self.post_total_cleanup
      manager.clear_failures_from_total
    end

    def self.example_passed?
      manager.test_passed?
    end

    def self.suite_passed?
      manager.total_passed?
    end

    def self.summarize_results
      manager.summarize_total_results_by_severity
    end

    def self.detailed_results
      manager.list_test_results
    end

    def self.configuration
      Stormbreaker.configuration
    end
  end
end
