# frozen_string_literal: true

require 'yaml'

module Stormbreaker
  class AxeResultsSerializer
    ALLOWED_CLASSES = [Stormbreaker::AxeViolation, Set, Symbol].freeze

    def self.serialize_results(total_violations)
      dump = YAML.dump(total_violations)
      prefix = Stormbreaker.configuration.serialize_prefix
      filename = "#{prefix}_#{Time.now.utc.strftime('%Y%m%d%H%M%S')}_#{Digest::SHA2.hexdigest(dump)}"
      File.open(filename, 'w') do |f|
        f.write(dump)
      end
      puts "Serialized results written to #{filename}"
    end

    def self.combine_results(path = Dir.pwd, prefix = nil)
      prefix ||= Stormbreaker.configuration.serialize_prefix
      results_files = Dir.glob(File.join(path, "#{prefix}*"))
      raise "No results matching /#{prefix}* found in #{path}" if results_files.empty?

      combined_manager = Stormbreaker::AxeViolationManager.new
      results_files.each do |file|
        puts "Loading #{file}"
        total_violations = YAML.safe_load(File.read(file), permitted_classes: ALLOWED_CLASSES)
        total_violations.each do |violation|
          combined_manager.add_failure_to_total(violation)
        end
      end

      combined_manager
    end
  end
end
