# frozen_string_literal: true

module Stormbreaker
  ALL_SEVERITY_CATEGORIES = %i[critical serious moderate minor].freeze

  def self.configuration
    @configuration ||= Configuration.new
  end

  def self.reset!
    @configuration = Configuration.new
  end

  def self.configure
    yield(configuration)
  end

  class Configuration
    attr_accessor :rules, :skip, :driver, :enabled_severity_categories, :results_path
    attr_accessor :serialize_output, :serialized_input_path, :serialize_prefix

    def initialize
      @rules = %i[wcag2a wcag2aa section508]
      @skip = %i[color-contrast duplicate-id]
      @enabled_severity_categories = ALL_SEVERITY_CATEGORIES
      @driver = nil
      @results_path = 'results.html'
      @serialize_output = false
      @serialized_input_path = '.'
      @serialize_prefix = 'stormbreaker_results'
    end
  end

  def self.configured_driver
    # Driver may be a lambda
    @configured_driver ||= if configuration.driver.respond_to?(:call)
      configuration.driver.call
    else
      configuration.driver
    end
  end
end
