# frozen_string_literal: true

require 'erb'

module Stormbreaker
  class ErbFormatter
    include ERB::Util
    attr_reader :violations

    def initialize(violations)
      @violations = sort_violations(violations)
      @severity_categories = Stormbreaker.configuration.enabled_severity_categories
    end

    def sort_violations(violations)
      sorted = {}
      Stormbreaker.configuration.enabled_severity_categories.each do |severity|
        sorted[severity] = violations.select { |v| v.severity == severity }
      end
      sorted
    end

    def write_to_erb
      erb = ERB.new(template)
      File.open(Stormbreaker.configuration.results_path, 'w') do |f|
        f.write erb.result(binding)
      end
      puts "Results written to #{Stormbreaker.configuration.results_path}"
    end

    def total_violations
      @violations.reduce(0) { |key, (_category, violations)| key + violations.count }
    end

    def failing_spec_count(violation)
      return if violation.called_by.to_a.empty?

      violation.called_by.to_a.map { |spec| spec.to_s.match(/(.*):/) }.uniq.count
    end

    def parse_callstack(violation)
      return if violation.called_by.to_a.empty?

      violation.called_by.to_a.map { |spec| "  #{spec}" }.join("\n")
    end

    def template
      File.read(File.join(File.dirname(__FILE__), '../templates/results.erb'))
    end
  end
end
